@@ -1,18 +1,19 @@
 # coding=utf-8
+import json
 
 
 class BinanceAPIException(Exception):
 
-    def __init__(self, response):
+    def __init__(self, response, status_code, text):
         self.code = 0
         try:
-            json_res = response.json()
+            json_res = json.loads(text)
         except ValueError:
             self.message = 'Invalid JSON error message from Binance: {}'.format(response.text)
         else:
             self.code = json_res['code']
             self.message = json_res['msg']
-        self.status_code = response.status_code
+        self.status_code = status_code
         self.response = response
         self.request = getattr(response, 'request', None)
 
@@ -42,42 +43,42 @@ class BinanceOrderMinAmountException(BinanceOrderException):
 
     def __init__(self, value):
         message = "Amount must be a multiple of %s" % value
-        super(BinanceOrderMinAmountException, self).__init__(-1013, message)
+        super().__init__(-1013, message)
 
 
 class BinanceOrderMinPriceException(BinanceOrderException):
 
     def __init__(self, value):
         message = "Price must be at least %s" % value
-        super(BinanceOrderMinPriceException, self).__init__(-1013, message)
+        super().__init__(-1013, message)
 
 
 class BinanceOrderMinTotalException(BinanceOrderException):
 
     def __init__(self, value):
         message = "Total must be at least %s" % value
-        super(BinanceOrderMinTotalException, self).__init__(-1013, message)
+        super().__init__(-1013, message)
 
 
 class BinanceOrderUnknownSymbolException(BinanceOrderException):
 
     def __init__(self, value):
         message = "Unknown symbol %s" % value
-        super(BinanceOrderUnknownSymbolException, self).__init__(-1013, message)
+        super().__init__(-1013, message)
 
 
 class BinanceOrderInactiveSymbolException(BinanceOrderException):
 
     def __init__(self, value):
         message = "Attempting to trade an inactive symbol %s" % value
-        super(BinanceOrderInactiveSymbolException, self).__init__(-1013, message)
+        super().__init__(-1013, message)
 
 
-class BinanceWithdrawException(Exception):
-    def __init__(self, message):
-        if message == u'参数异常':
-            message = 'Withdraw to this address through the website first'
-        self.message = message
+class BinanceWebsocketUnableToConnect(Exception):
+    pass
 
-    def __str__(self):
-        return 'BinanceWithdrawException: %s' % self.message
+
+class NotImplementedException(Exception):
+    def __init__(self, value):
+        message = f'Not implemented: {value}'
+        super().__init__(message)
